import tkinter as tk
from tkinter import ttk, messagebox

class AlarmApp:
    def __init__(self, root):
        self.root = root
        self.root.title("Windows Alarm & Shutdown Scheduler")
        self.root.geometry("400x500")
        
        self.alarms = []  # 알람 저장 리스트
        
        # 요일 선택 체크박스
        self.days_frame = tk.LabelFrame(root, text="요일 선택")
        self.days_frame.pack(pady=5)
        
        self.days = ["월", "화", "수", "목", "금", "토", "일"]
        self.day_vars = {day: tk.BooleanVar() for day in self.days}
        
        for day, var in self.day_vars.items():
            chk = tk.Checkbutton(self.days_frame, text=day, variable=var)
            chk.pack(side=tk.LEFT)
        
        # 시간 선택
        self.time_frame = tk.LabelFrame(root, text="알람 시간 설정")
        self.time_frame.pack(pady=5)
        
        self.hour_var = tk.StringVar()
        self.minute_var = tk.StringVar()
        
        self.hour_combo = ttk.Combobox(self.time_frame, textvariable=self.hour_var, values=[str(i).zfill(2) for i in range(24)], width=5)
        self.hour_combo.pack(side=tk.LEFT, padx=5)
        self.minute_combo = ttk.Combobox(self.time_frame, textvariable=self.minute_var, values=["00", "10", "20", "30", "40", "50"], width=5)
        self.minute_combo.pack(side=tk.LEFT)
        
        # 알람 메시지 입력
        self.msg_frame = tk.LabelFrame(root, text="알람 메시지")
        self.msg_frame.pack(pady=5)
        
        self.msg_entry = tk.Entry(self.msg_frame, width=30)
        self.msg_entry.pack(padx=5, pady=5)
        self.msg_entry.insert(0, "알람")  # 기본 메시지 설정
        
        # 버튼들
        self.btn_frame = tk.Frame(root)
        self.btn_frame.pack(pady=5)
        
        self.add_btn = tk.Button(self.btn_frame, text="알람 등록", width=10, command=self.add_alarm)
        self.add_btn.pack(side=tk.LEFT, padx=5)
        self.update_btn = tk.Button(self.btn_frame, text="수정", width=10, command=self.update_alarm)
        self.update_btn.pack(side=tk.LEFT, padx=5)
        self.delete_btn = tk.Button(self.btn_frame, text="삭제", width=10, command=self.delete_alarm)
        self.delete_btn.pack(side=tk.LEFT, padx=5)
        
        # 등록된 알람 리스트
        self.list_frame = tk.LabelFrame(root, text="등록된 알람")
        self.list_frame.pack(pady=5)
        
        self.alarm_listbox = tk.Listbox(self.list_frame, width=50, height=10)
        self.alarm_listbox.pack(padx=5, pady=5)
        self.alarm_listbox.bind("<<ListboxSelect>>", self.load_selected_alarm)
        
        # 예약 종료 기능
        self.shutdown_frame = tk.LabelFrame(root, text="예약 종료 설정")
        self.shutdown_frame.pack(pady=5)
        
        self.shutdown_hour_var = tk.StringVar()
        self.shutdown_minute_var = tk.StringVar()
        
        self.shutdown_hour_combo = ttk.Combobox(self.shutdown_frame, textvariable=self.shutdown_hour_var, values=[str(i).zfill(2) for i in range(24)], width=5)
        self.shutdown_hour_combo.pack(side=tk.LEFT, padx=5)
        self.shutdown_minute_combo = ttk.Combobox(self.shutdown_frame, textvariable=self.shutdown_minute_var, values=["00", "10", "20", "30", "40", "50"], width=5)
        self.shutdown_minute_combo.pack(side=tk.LEFT)
        
        self.shutdown_btn = tk.Button(self.shutdown_frame, text="예약 종료", width=10)
        self.shutdown_btn.pack(side=tk.LEFT, padx=5)
        self.cancel_btn = tk.Button(self.shutdown_frame, text="취소", width=10)
        self.cancel_btn.pack(side=tk.LEFT, padx=5)
    
    def add_alarm(self):
        selected_days = [day for day, var in self.day_vars.items() if var.get()]
        hour = self.hour_var.get()
        minute = self.minute_var.get()
        message = self.msg_entry.get().strip() or "알람"
        
        if not selected_days:
            messagebox.showwarning("입력 오류", "적어도 하나의 요일을 선택하세요.")
            return
        
        if not hour or not minute:
            messagebox.showwarning("입력 오류", "시간을 설정하세요.")
            return
        
        alarm_entry = f"{', '.join(selected_days)} - {hour}:{minute} - {message}"
        self.alarms.append(alarm_entry)
        self.alarm_listbox.insert(tk.END, alarm_entry)
        self.clear_fields()
    
    def delete_alarm(self):
        selected_index = self.alarm_listbox.curselection()
        if not selected_index:
            messagebox.showwarning("삭제 오류", "삭제할 알람을 선택하세요.")
            return
        
        self.alarm_listbox.delete(selected_index)
        del self.alarms[selected_index[0]]
    
    def update_alarm(self):
        selected_index = self.alarm_listbox.curselection()
        if not selected_index:
            messagebox.showwarning("수정 오류", "수정할 알람을 선택하세요.")
            return
        
        selected_days = [day for day, var in self.day_vars.items() if var.get()]
        hour = self.hour_var.get()
        minute = self.minute_var.get()
        message = self.msg_entry.get().strip() or "알람"
        
        if not selected_days:
            messagebox.showwarning("입력 오류", "적어도 하나의 요일을 선택하세요.")
            return
        
        if not hour or not minute:
            messagebox.showwarning("입력 오류", "시간을 설정하세요.")
            return
        
        alarm_entry = f"{', '.join(selected_days)} - {hour}:{minute} - {message}"
        self.alarms[selected_index[0]] = alarm_entry
        self.alarm_listbox.delete(selected_index)
        self.alarm_listbox.insert(selected_index, alarm_entry)
        self.clear_fields()
    
    def load_selected_alarm(self, event):
        selected_index = self.alarm_listbox.curselection()
        if not selected_index:
            return
        
        alarm_entry = self.alarms[selected_index[0]]
        days_part, time_part, message = alarm_entry.split(" - ")
        
        for var in self.day_vars.values():
            var.set(False)
        for day in days_part.split(", "):
            if day in self.day_vars:
                self.day_vars[day].set(True)
        
        hour, minute = time_part.split(":")
        self.hour_var.set(hour)
        self.minute_var.set(minute)
        self.msg_entry.delete(0, tk.END)
        self.msg_entry.insert(0, message)
    
    def clear_fields(self):
        for var in self.day_vars.values():
            var.set(False)
        self.hour_var.set("")
        self.minute_var.set("")
        self.msg_entry.delete(0, tk.END)
        self.msg_entry.insert(0, "알람")

if __name__ == "__main__":
    root = tk.Tk()
    app = AlarmApp(root)
    root.mainloop()
